"""
Helpers for specific patterns of usage.
"""

from configurator import Config


def load_with_extends(path, key):
    configs = []
    while path:
        config = Config.from_path(path)
        configs.append(config)
        path = config.get(key)
    config = Config()
    for layer in reversed(configs):
        config.merge(layer)
    config.data.pop(key, None)
    return config



from testfixtures import compare

from configurator import Config
from configurator.patterns import load_with_extends


def test_load_with_extends_key_not_present(dir):
    path = dir.write('file.json', '{"key":"value"}')
    compare(load_with_extends(path, key='extends'), expected=Config({'key': 'value'}))
